==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/activity/messages/pt/base.php <==
<?php
return array (
  '<strong>E-Mail</strong> Summaries' => '<strong>E-Mails</strong> com Resumos',
  '<strong>Latest</strong> activities' => '<strong>Últimas</strong> actividades',
  'Activities' => 'Actividades',
  'Daily' => 'Diário',
  'E-Mail Summaries' => 'E-Mails com Resumos',
  'E-Mail summaries are sent to inform you about recent activities in the network.' => 'E-Mails com Resumos são enviados para te informar sobre actividades recentes na rede.',
  'E-Mail summaries are sent to users to inform them about recent activities in your network.' => 'E-Mails com Resumos são enviados para informar utilizadores sobre actividades recentes na tua rede.',
  'Exclude spaces below from the mail summary' => 'Excluir os espaços abaixo do resumo de e-mail',
  'Hourly' => 'Horário',
  'Interval' => 'Intervalo',
  'Latest news' => 'Últimas notícias',
  'Never' => 'Nunca',
  'On this page you can configure the contents and the interval of these e-mail updates.' => 'Nesta página podes configurar os conteúdos e o intervalo destas atualizações por e-mail.',
  'On this page you can define the default behavior for your users. These settings can be overwritten by users in their account settings page.' => 'Nesta página podes definir o comportamento padrão para os utilizadores. Estas definições podem ser substituídas individualmente pelos utilizadores nas respectivas páginas de definições de conta.',
  'Only include spaces below to the mail summary' => 'Incluir apenas os espaços abaixo no e-mail com resumos',
  'Reset to defaults' => 'Restabelecer os valores padrão',
  'See online:' => 'Ver online:',
  'Spaces' => 'Espaços',
  'There are no activities yet.' => 'Ainda não há actividade.',
  'Weekly' => 'Semanal',
  'You will only receive an e-mail if there is something new.' => 'Só vais receber um e-mail se houver algo novo.',
  'Your daily summary' => 'O teu resumo diário',
  'Your weekly summary' => 'O teu resumo semanal',
  'see online' => 'ver online',
  'via' => 'via',
  '{displayName} created the new space {spaceName}' => '{displayName} criou o novo espaço {spaceName}',
  '{displayName} created this space.' => '{displayName} criou este espaço.',
  '{displayName} joined the space {spaceName}' => '{displayName} entrou no espaço {spaceName}',
  '{displayName} joined this space.' => '{displayName} entrou neste espaço.',
  '{displayName} left the space {spaceName}' => '{displayName} saiu do espaço {spaceName}',
  '{displayName} left this space.' => '{displayName} saiu deste espaço.',
  '{spaceName} has been archived' => '{spaceName} foi arquivado',
  '{spaceName} has been unarchived' => '{spaceName} foi desarquivado',
  '{user1} now follows {user2}.' => '{user1} agora segue {user2}.',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/activity/messages/pt/base.php <==
<?php
return array (
  '<strong>E-Mail</strong> Summaries' => '<strong>E-Mails</strong> com Resumos',
  '<strong>Latest</strong> activities' => '<strong>Últimas</strong> atividades',
  'Activities' => 'Atividades',
  'Daily' => 'Diário',
  'E-Mail Summaries' => 'E-Mails com Resumos',
  'E-Mail summaries are sent to inform you about recent activities in the network.' => 'E-Mails com Resumos são enviados para te informar sobre atividades recentes na rede.',
  'E-Mail summaries are sent to users to inform them about recent activities in your network.' => 'E-Mails com Resumos são enviados para informar utilizadores sobre atividades recentes na tua rede.',
  'Exclude spaces below from the mail summary' => 'Excluir os espaços abaixo do resumo de e-mail',
  'Hourly' => 'Horário',
  'Interval' => 'Intervalo',
  'Latest news' => 'Últimas notícias',
  'Never' => 'Nunca',
  'On this page you can configure the contents and the interval of these e-mail updates.' => 'Nesta página podes configurar os conteúdos e o intervalo destas atualizações por e-mail.',
  'On this page you can define the default behavior for your users. These settings can be overwritten by users in their account settings page.' => 'Nesta página podes definir o comportamento padrão para os utilizadores. Estas definições podem ser substituídas individualmente pelos utilizadores nas respetivas páginas de definições de conta.',
  'Only include spaces below to the mail summary' => 'Incluir apenas os espaços abaixo no e-mail com resumos',
  'Reset to defaults' => 'Restabelecer os valores padrão',
  'See online:' => 'Ver online:',
  'Spaces' => 'Espaços',
  'There are no activities yet.' => 'Ainda não há atividades.',
  'Weekly' => 'Semanal',
  'You will only receive an e-mail if there is something new.' => 'Só vais receber um e-mail se houver algo novo.',
  'Your daily summary' => 'O teu resumo diário',
  'Your weekly summary' => 'O teu resumo semanal',
  'see online' => 'ver online',
  'via' => 'via',
  '{displayName} created the new space {spaceName}' => '{displayName} criou o novo espaço {spaceName}',
  '{displayName} created this space.' => '{displayName} criou este espaço.',
  '{displayName} joined the space {spaceName}' => '{displayName} entrou no espaço {spaceName}',
  '{displayName} joined this space.' => '{displayName} entrou neste espaço.',
  '{displayName} left the space {spaceName}' => '{displayName} saiu do espaço {spaceName}',
  '{displayName} left this space.' => '{displayName} saiu deste espaço.',
  '{spaceName} has been archived' => '{spaceName} foi arquivado',
  '{spaceName} has been unarchived' => '{spaceName} foi desarquivado',
  '{user1} now follows {user2}.' => '{user1} agora segue {user2}.',
);
